/////////////////////////////////////////////////////////////////////////////////////
// File:	oraclefunc.h
// Author:	Walt Jones
// Email:	wjones@blarg.net
// Date:	29 July, 2000
// Project:	ResNet Autoreg v2.0
// Purpose:	Provides functions that format strings needed for Oracle's Pro*C++
/////////////////////////////////////////////////////////////////////////////////////

#include <stdlib.h>
#include <string>
#include "conf.h"
#include "configfile.h"

typedef enum {
	TYPE_IP,
	TYPE_MACH,
	TYPE_USER,
	TYPE_HUBLOAN,
	TYPE_HUB,
	TYPE_CHARGE
} sqlLookupType;

char *getOracleEnvString();
char *getConnectString();
string getSQLwhere(const string &lookupString, const string &lookby, const sqlLookupType &type, string &orderByCol);

char *getOracleEnvString()
{
	string envString = "ORACLE_HOME=" + string(ORACLE_HOME);
	char *env = new char[envString.length()+1];
	strcpy(env, envString.c_str());
	return env;
}

char *getConnectString()
{
	configFileInterface aregconf(CONF_FILE);
	string dbName;
	char *connectString;
	
	// Get the path of our dhcp.conf file and create a new dhcpConfInterface for it
	if (aregconf.open() == configFileSuccess)
	{
		if (aregconf.getDB(dbName) == configFileSuccess)
		{
			connectString = new char[strlen(ORACLE_USERNAME) + strlen(ORACLE_PASSWORD) + dbName.length() + 3];
			strcpy(connectString, (string(ORACLE_USERNAME) + "/" + string(ORACLE_PASSWORD) + "@" + dbName).c_str());
		}
		aregconf.close();
	}
	return connectString;
}

string getSQLwhere(const string &lookupString, const string &lookby, const sqlLookupType &type, string &orderByCol)
{
	string sqlWhere;
	bool likeStmt = false;
	bool inStmt = false;
	
	if (lookupString.find("%",0) != string::npos)
		likeStmt = true;
	else if (lookupString.find(",",0) != string::npos)
		inStmt = true;	
	
	if (type == TYPE_USER)
	{
		if (lookby == "oisID")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ois_person_id LIKE '" + lookupString + "'";
			else if (inStmt)
				sqlWhere = "ois_person_view.ois_person_id IN (" + lookupString + ")";
			else
				sqlWhere = "ois_person_view.ois_person_id=" + lookupString;
			orderByCol = "username";
		}
		else if (lookby == "mac")
		{
			if (likeStmt)
				sqlWhere = "mac_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "mac_addr='" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "ip")
		{
			if (likeStmt)
				sqlWhere = "ip_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "ip_addr='" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "subnet")
		{
			if (likeStmt)
				sqlWhere = "subnet LIKE '" + lookupString + "'";
			else
				sqlWhere = "subnet='" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "hostname")
		{
			if (likeStmt)
				sqlWhere = "hostname LIKE '" + lookupString + "'";
			else
				sqlWhere = "hostname='" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "regdate")
		{
			sqlWhere = "TO_CHAR(reg_date, 'MM/DD/YYYY') LIKE '" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "username";
		}
		else if (lookby == "upsid")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.upsid LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.upsid=" + lookupString;
			orderByCol = "upsid";
		}
		else if (lookby == "ssn")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ssn LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.ssn='" + lookupString + "'";
			orderByCol = "ssn";
		}
		else if (lookby == "prefname")
		{
			if (likeStmt)
				sqlWhere = "preferred_first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "preferred_first_name='" + lookupString + "'";
			orderByCol = "preferred_first_name";
		}
		else if (lookby == "firstname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.first_name='" + lookupString + "'";
			orderByCol = "first_name";
		}
		else if (lookby == "lastname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.last_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.last_name='" + lookupString + "'";
			orderByCol = "last_name";
		}
		else if (lookby == "email")
		{
			if (likeStmt)
				sqlWhere = "LOWER(e_mail_address) LIKE '" + lookupString + "'";
			else
				sqlWhere = "LOWER(e_mail_address)='" + lookupString + "'";
			orderByCol = "e_mail_address";
		}
		else if (lookby == "phone")
		{
			if (likeStmt)
				sqlWhere = "resnet_phone LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_phone='" + lookupString + "'";
			orderByCol = "resnet_phone";
		}
		else if (lookby == "room")
		{
			if (likeStmt)
				sqlWhere = "resnet_room LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_room='" + lookupString + "'";
			orderByCol = "resnet_room";
		}
		else if (lookby == "building")
		{
			if (likeStmt)
				sqlWhere = "resnet_bldg LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_bldg='" + lookupString + "'";
			orderByCol = "resnet_bldg";
		}
	}
	else if (type == TYPE_MACH)
	{
		if (lookby == "machID")
		{
			if (likeStmt)
				sqlWhere = "machine_id LIKE '" + lookupString + "'";
			else if (inStmt)
				sqlWhere = "machine_id IN (" + lookupString + ")";
			else
				sqlWhere = "machine_id=" + lookupString;
			orderByCol = "mac_addr";
		}
		else if (lookby == "mac")
		{
			if (likeStmt)
				sqlWhere = "mac_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "mac_addr='" + lookupString + "'";
			orderByCol = "mac_addr";
		}
		else if (lookby == "ip")
		{
			if (likeStmt)
				sqlWhere = "ip_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "ip_addr='" + lookupString + "'";
			orderByCol = "ip_addr";
		}
		else if (lookby == "subnet")
		{
			if (likeStmt)
				sqlWhere = "subnet LIKE '" + lookupString + "'";
			else
				sqlWhere = "subnet='" + lookupString + "'";
			orderByCol = "ip_addr";
		}
		else if (lookby == "netmask")
		{
			if (likeStmt)
				sqlWhere = "subnet_mask LIKE '" + lookupString + "'";
			else
				sqlWhere = "subnet_mask='" + lookupString + "'";
			orderByCol = "ip_addr";
		}
		else if (lookby == "hostname")
		{
			if (likeStmt)
				sqlWhere = "hostname LIKE '" + lookupString + "'";
			else
				sqlWhere = "hostname='" + lookupString + "'";
			orderByCol = "hostname";
		}
		else if (lookby == "regdate")
		{
			sqlWhere = "TO_CHAR(reg_date, 'MM/DD/YYYY') LIKE '" + lookupString + "'";
			orderByCol = "reg_date";
		}
		else if (lookby == "systemtype")
		{
			if (likeStmt)
				sqlWhere = "system_type LIKE '" + lookupString + "'";
			else
				sqlWhere = "system_type='" + lookupString + "'";
			orderByCol = "system_type";
		}
		else if (lookby == "man")
		{
			if (likeStmt)
				sqlWhere = "manufacturer LIKE '" + lookupString + "'";
			else
				sqlWhere = "manufacturer='" + lookupString + "'";
			orderByCol = "manufacturer";
		}
		else if (lookby == "os")
		{
			if (likeStmt)
				sqlWhere = "os_type LIKE '" + lookupString + "'";
			else
				sqlWhere = "os_type='" + lookupString + "'";
			orderByCol = "os_type";
		}
		else if (lookby == "nic")
		{
			if (likeStmt)
				sqlWhere = "nic_type LIKE '" + lookupString + "'";
			else
				sqlWhere = "nic_type='" + lookupString + "'";
			orderByCol = "nic_type";
		}
		else if (lookby == "regtype")
		{
			if (likeStmt)
				sqlWhere = "reg_type LIKE '" + lookupString + "'";
			else
				sqlWhere = "reg_type='" + lookupString + "'";
			orderByCol = "reg_type";
		}
		else if (lookby == "bootp")
		{
			if (likeStmt)
				sqlWhere = "bootp_allowed LIKE '" + lookupString + "'";
			else
				sqlWhere = "bootp_allowed='" + lookupString + "'";
			orderByCol = "bootp_allowed";
		}
		else if (lookby == "usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "upsid")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.upsid LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.upsid=" + lookupString;
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "ssn")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ssn LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.ssn='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "prefname")
		{
			if (likeStmt)
				sqlWhere = "preferred_first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "preferred_first_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "firstname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.first_name='" + lookupString + "'";
			orderByCol = "ois_person_view.ups_e_mail_address_base.username";
		}
		else if (lookby == "lastname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.last_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.last_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "email")
		{
			if (likeStmt)
				sqlWhere = "LOWER(e_mail_address) LIKE '" + lookupString + "'";
			else
				sqlWhere = "LOWER(e_mail_address)='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "phone")
		{
			if (likeStmt)
				sqlWhere = "resnet_phone LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_phone='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "room")
		{
			if (likeStmt)
				sqlWhere = "resnet_room LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_room='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
	}
	else if (type == TYPE_IP)
	{
		if (lookby == "ipID")
		{
			if (likeStmt)
				sqlWhere = "ip_addr.ip_addr_id LIKE '" + lookupString + "'";
			else if (inStmt)
				sqlWhere = "ip_addr.ip_addr_id IN (" + lookupString + ")";
			else
				sqlWhere = "ip_addr.ip_addr_id=" + lookupString;
			orderByCol = "ip_addr";
		}
		else if (lookby == "mac")
		{
			if (likeStmt)
				sqlWhere = "mac_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "mac_addr='" + lookupString + "'";
			orderByCol = "mac_addr";
		}
		else if (lookby == "ip")
		{
			if (likeStmt)
				sqlWhere = "ip_addr LIKE '" + lookupString + "'";
			else
				sqlWhere = "ip_addr='" + lookupString + "'";
			orderByCol = "ip_addr";
		}
		else if (lookby == "subnet")
		{
			if (likeStmt)
				sqlWhere = "subnet LIKE '" + lookupString + "'";
			else
				sqlWhere = "subnet='" + lookupString + "'";
			orderByCol = "subnet";
		}
		else if (lookby == "netmask")
		{
			if (likeStmt)
				sqlWhere = "subnet_mask LIKE '" + lookupString + "'";
			else
				sqlWhere = "subnet_mask='" + lookupString + "'";
			orderByCol = "subnet_mask";
		}
		else if (lookby == "usage")
		{
			if (likeStmt)
				sqlWhere = "usage LIKE '" + lookupString + "'";
			else
				sqlWhere = "usage='" + lookupString + "'";
			orderByCol = "usage";
		}
		else if (lookby == "usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
	}
	else if (type == TYPE_CHARGE)
	{
		if (lookby == "oisID")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ois_person_id LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.ois_person_id=" + lookupString;
			orderByCol = "add_date";
		}
		else if (lookby == "usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "upsid")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.upsid LIKE '" + lookupString + "'"; 
			else
				sqlWhere = "ois_person_view.upsid=" + lookupString;
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "ssn")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ssn LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.ssn='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "prefname")
		{
			if (likeStmt)
				sqlWhere = "preferred_first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "preferred_first_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "firstname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.first_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "lastname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.last_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.last_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "email")
		{
			if (likeStmt)
				sqlWhere = "LOWER(e_mail_address) LIKE '" + lookupString + "'";
			else
				sqlWhere = "LOWER(e_mail_address)='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "phone")
		{
			if (likeStmt)
				sqlWhere = "resnet_phone LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_phone='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
	}
	else if (type == TYPE_HUBLOAN)
	{
		if (lookby == "hubloanID")
		{
			if (likeStmt)
				sqlWhere = "hub_loan_id LIKE '" + lookupString + "'";
			else if (inStmt)
				sqlWhere = "hub_loan_id IN (" + lookupString + ")";
			else
				sqlWhere = "hub_loan_id=" + lookupString;
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "upsid")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.upsid LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.upsid=" + lookupString;
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "ssn")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.ssn LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.ssn='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "prefname")
		{
			if (likeStmt)
				sqlWhere = "preferred_first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "preferred_first_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "firstname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.first_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.first_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "lastname")
		{
			if (likeStmt)
				sqlWhere = "ois_person_view.last_name LIKE '" + lookupString + "'";
			else
				sqlWhere = "ois_person_view.last_name='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "email")
		{
			if (likeStmt)
				sqlWhere = "LOWER(e_mail_address) LIKE '" + lookupString + "'";
			else
				sqlWhere = "LOWER(e_mail_address)='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "phone")
		{
			if (likeStmt)
				sqlWhere = "resnet_phone LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_phone='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "room")
		{
			if (likeStmt)
				sqlWhere = "resnet_room LIKE '" + lookupString + "'";
			else
				sqlWhere = "resnet_room='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "hubsn")
		{
			if (likeStmt)
				sqlWhere = "hub_sn LIKE '" + lookupString + "'";
			else
				sqlWhere = "hub_sn='" + lookupString + "'";
			orderByCol = "hub_sn";
		}
		else if (lookby == "huboutdate")
		{
			sqlWhere = "TO_CHAR(check_out_date, 'MM/DD/YYYY') LIKE '" + lookupString + "'";
			orderByCol = "check_out_date";
		}
	}
	else if (type == TYPE_HUB)
	{
		if (lookby == "oisID")
		{
			if (likeStmt)
				sqlWhere = "resnet_user.ois_person_id LIKE '" + lookupString + "'";
			else if (inStmt)
				sqlWhere = "resnet_user.ois_person_id IN (" + lookupString + ")";
			else
				sqlWhere = "resnet_user.ois_person_id=" + lookupString;
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "hubID")
		{
			if (likeStmt)
				sqlWhere = "hub.hub_id LIKE '" + lookupString + "'";
			else
				sqlWhere = "hub.hub_id=" + lookupString;
			orderByCol = "hub_id";
		}
		else if (lookby == "hubloanID")
		{
			if (likeStmt)
				sqlWhere = "hub_loan.hub_loan_id LIKE '" + lookupString + "'";
			else
				sqlWhere = "hub_loan.hub_loan_id=" + lookupString;
			orderByCol = "hub_loan_id";
		}
		else if (lookby == "hub_loan.usrname")
		{
			if (likeStmt)
				sqlWhere = "ups_e_mail_address_base.username LIKE '" + lookupString + "'";
			else
				sqlWhere = "ups_e_mail_address_base.username='" + lookupString + "'";
			orderByCol = "ups_e_mail_address_base.username";
		}
		else if (lookby == "hubsn")
		{
			if (likeStmt)
				sqlWhere = "hub_sn LIKE '" + lookupString + "'";
			else
				sqlWhere = "hub_sn='" + lookupString + "'";
			orderByCol = "hub_sn";
		}
		else if (lookby == "hubtype")
		{
			if (likeStmt)
				sqlWhere = "hub_type LIKE '" + lookupString + "'";
			else
				sqlWhere = "hub_type='" + lookupString + "'";
			orderByCol = "hub_type";
		}
		else if (lookby == "huboutdate")
		{
			sqlWhere = "TO_CHAR(reg_date, 'MM/DD/YYYY') LIKE '" + lookupString + "'";
			orderByCol = "check_out_date";
		}
		else if (lookby == "hubindate")
		{
			sqlWhere = "TO_CHAR(reg_date, 'MM/DD/YYYY') LIKE '" + lookupString + "'";
			orderByCol = "check_in_date";
		}
	}

	return sqlWhere;			
}

